@@ -373,6 +373,14 @@ pub enum CallKind {
         )]
         #[serde(default)]
         omit_read_position_bias: bool,
+        #[structopt(
+            long = "omit-softclip-bias",
+            help = "Do not consider softclip bias when calculating the probability of an \
+                    artifact. Use this flag when processing (panel) sequencing data, where the \
+                    wet-lab methodology leads to stacks of reads starting at the same position."
+        )]
+        #[serde(default)]
+        omit_softclip_bias: bool,
         #[structopt(
             long = "testcase-locus",
             help = "Create a test case for the given locus. Locus must be given in the form \
@@ -387,6 +395,11 @@ pub enum CallKind {
             help = "Create test case files in the given directory."
         )]
         testcase_prefix: Option<String>,
+        #[structopt(
+            long = "testcase-anonymous",
+            help = "Anonymize any identifiers (via uuid4) and the sequences (by randomly permuting the alphabet) in the test case."
+        )]
+        testcase_anonymous: bool,
         #[structopt(
             long,
             short,
@@ -667,8 +680,10 @@ pub fn run(opt: Varlociraptor) -> Result<()> {
                     omit_strand_bias,
                     omit_read_orientation_bias,
                     omit_read_position_bias,
+                    omit_softclip_bias,
                     testcase_locus,
                     testcase_prefix,
+                    testcase_anonymous,
                     output,
                 } => {
                     let testcase_builder = if let Some(testcase_locus) = testcase_locus {
@@ -677,6 +692,7 @@ pub fn run(opt: Varlociraptor) -> Result<()> {
                             Some(
                                 testcase::TestcaseBuilder::default()
                                     .prefix(PathBuf::from(testcase_prefix))
+                                    .anonymize(testcase_anonymous)
                                     .locus(&testcase_locus)?,
                             )
                         } else {
@@ -742,6 +758,7 @@ pub fn run(opt: Varlociraptor) -> Result<()> {
                             .omit_strand_bias(omit_strand_bias)
                             .omit_read_orientation_bias(omit_read_orientation_bias)
                             .omit_read_position_bias(omit_read_position_bias)
+                            .omit_softclip_bias(omit_softclip_bias)
                             .scenario(scenario)
                             .prior(prior)
                             .contaminations(sample_infos.contaminations)
@@ -774,7 +791,7 @@ pub fn run(opt: Varlociraptor) -> Result<()> {
                                         testcase_builder = testcase_builder.register_sample(
                                             &sample_name,
                                             preprocess_input.bam,
-                                            &options,
+                                            options,
                                         )?;
                                         if i == 0 {
                                             testcase_builder =
@@ -821,12 +838,12 @@ pub fn run(opt: Varlociraptor) -> Result<()> {
                                     .register_sample(
                                         "tumor",
                                         tumor_options.preprocess_input().bam,
-                                        &tumor_options,
+                                        tumor_options,
                                     )?
                                     .register_sample(
                                         "normal",
                                         normal_options.preprocess_input().bam,
-                                        &normal_options,
+                                        normal_options,
                                     )?
                                     .scenario(None)
                                     .mode(testcase::Mode::TumorNormal)
